@@ -5,16 +5,14 @@ use swipl_info::*;
 
 fn main() {
     let info = get_swipl_info();
-    println!("cargo:rustc-link-lib=swipl");
-    println!(
-        "cargo:rustc-link-search={}/{}",
-        info.swi_home, info.pack_so_dir
-    );
-
+    println!("cargo:rustc-link-lib={}", info.lib_name);
+    println!("cargo:rustc-link-search={}", info.lib_dir);
     println!("cargo:rerun-if-changed=c/wrapper.h");
+    println!("cargo:rerun-if-env-changed=SWIPL");
+
     let bindings = bindgen::Builder::default()
         .header("c/wrapper.h")
-        .clang_arg(format!("-I{}/include", info.swi_home))
+        .clang_arg(format!("-I{}", info.header_dir))
         .parse_callbacks(Box::new(bindgen::CargoCallbacks))
         .generate()
         .unwrap();
